lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [lmi] master cc7fc05 143/156: Change template file extensi


From: Greg Chicares
Subject: [lmi-commits] [lmi] master cc7fc05 143/156: Change template file extension from .mustache to .mst
Date: Tue, 30 Jan 2018 17:22:33 -0500 (EST)

branch: master
commit cc7fc05fb9bd392079c6810c166848d32916936a
Author: Vadim Zeitlin <address@hidden>
Commit: Vadim Zeitlin <address@hidden>

    Change template file extension from .mustache to .mst
    
    The .mst extension is non-standard, but leaves more space for the base
    names considering that the full name may only be at most 31 characters
    in lmi.
---
 column_headings.mustache => column_headings.mst                     | 0
 ...iance_tracking_number.mustache => compliance_tracking_number.mst | 0
 contract_numbers.mustache => contract_numbers.mst                   | 0
 cover.mustache => cover.mst                                         | 0
 dollar_units.mustache => dollar_units.mst                           | 0
 footer.mustache => footer.mst                                       | 0
 footer_disclaimer.mustache => footer_disclaimer.mst                 | 0
 header.mustache => header.mst                                       | 0
 ledger_pdf_generator_wx.cpp                                         | 6 +++---
 narrative_summary.mustache => narrative_summary.mst                 | 0
 narrative_summary_cont.mustache => narrative_summary_cont.mst       | 0
 nasd_assumption_detail.mustache => nasd_assumption_detail.mst       | 0
 nasd_basic.mustache => nasd_basic.mst                               | 0
 nasd_column_headings.mustache => nasd_column_headings.mst           | 0
 nasd_footer_lower.mustache => nasd_footer_lower.mst                 | 0
 nasd_footer_upper.mustache => nasd_footer_upper.mst                 | 0
 nasd_header.mustache => nasd_header.mst                             | 0
 nasd_header_lower.mustache => nasd_header_lower.mst                 | 0
 nasd_header_upper.mustache => nasd_header_upper.mst                 | 0
 nasd_notes1.mustache => nasd_notes1.mst                             | 0
 nasd_notes2.mustache => nasd_notes2.mst                             | 0
 nasd_supplemental.mustache => nasd_supplemental.mst                 | 0
 nasd_supplemental_report.mustache => nasd_supplemental_report.mst   | 0
 numeric_summary.mustache => numeric_summary.mst                     | 0
 reg_d_group_basic.mustache => reg_d_group_basic.mst                 | 0
 ...roup_column_headings.mustache => reg_d_group_column_headings.mst | 0
 reg_d_group_footer_lower.mustache => reg_d_group_footer_lower.mst   | 0
 reg_d_group_footer_upper.mustache => reg_d_group_footer_upper.mst   | 0
 reg_d_group_header.mustache => reg_d_group_header.mst               | 0
 reg_d_group_header_lower.mustache => reg_d_group_header_lower.mst   | 0
 reg_d_group_header_upper.mustache => reg_d_group_header_upper.mst   | 0
 ..._narrative_summary.mustache => reg_d_group_narrative_summary.mst | 0
 ...arrative_summary2.mustache => reg_d_group_narrative_summary2.mst | 0
 ...plemental_report.mustache => reg_d_group_supplemental_report.mst | 0
 ...ndividual_cover_page.mustache => reg_d_individual_cover_page.mst | 0
 reg_d_individual_cur.mustache => reg_d_individual_cur.mst           | 0
 reg_d_individual_cur_irr.mustache => reg_d_individual_cur_irr.mst   | 0
 ...idual_footer_lower.mustache => reg_d_individual_footer_lower.mst | 0
 ...idual_footer_upper.mustache => reg_d_individual_footer_upper.mst | 0
 reg_d_individual_guar_irr.mustache => reg_d_individual_guar_irr.mst | 0
 reg_d_individual_header.mustache => reg_d_individual_header.mst     | 0
 reg_d_individual_notes1.mustache => reg_d_individual_notes1.mst     | 0
 reg_d_individual_notes2.mustache => reg_d_individual_notes2.mst     | 0
 reg_d_individual_notes3.mustache => reg_d_individual_notes3.mst     | 0
 ...ntal_report.mustache => reg_d_individual_supplemental_report.mst | 0
 supplemental_report.mustache => supplemental_report.mst             | 0
 tabular_details.mustache => tabular_details.mst                     | 0
 tabular_details2.mustache => tabular_details2.mst                   | 0
 workhorse.make                                                      | 2 +-
 49 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/column_headings.mustache b/column_headings.mst
similarity index 100%
rename from column_headings.mustache
rename to column_headings.mst
diff --git a/compliance_tracking_number.mustache 
b/compliance_tracking_number.mst
similarity index 100%
rename from compliance_tracking_number.mustache
rename to compliance_tracking_number.mst
diff --git a/contract_numbers.mustache b/contract_numbers.mst
similarity index 100%
rename from contract_numbers.mustache
rename to contract_numbers.mst
diff --git a/cover.mustache b/cover.mst
similarity index 100%
rename from cover.mustache
rename to cover.mst
diff --git a/dollar_units.mustache b/dollar_units.mst
similarity index 100%
rename from dollar_units.mustache
rename to dollar_units.mst
diff --git a/footer.mustache b/footer.mst
similarity index 100%
rename from footer.mustache
rename to footer.mst
diff --git a/footer_disclaimer.mustache b/footer_disclaimer.mst
similarity index 100%
rename from footer_disclaimer.mustache
rename to footer_disclaimer.mst
diff --git a/narrative_summary.mustache b/narrative_summary.mst
similarity index 100%
rename from narrative_summary.mustache
rename to narrative_summary.mst
diff --git a/narrative_summary_cont.mustache b/narrative_summary_cont.mst
similarity index 100%
rename from narrative_summary_cont.mustache
rename to narrative_summary_cont.mst
diff --git a/nasd_assumption_detail.mustache b/nasd_assumption_detail.mst
similarity index 100%
rename from nasd_assumption_detail.mustache
rename to nasd_assumption_detail.mst
diff --git a/nasd_basic.mustache b/nasd_basic.mst
similarity index 100%
rename from nasd_basic.mustache
rename to nasd_basic.mst
diff --git a/nasd_column_headings.mustache b/nasd_column_headings.mst
similarity index 100%
rename from nasd_column_headings.mustache
rename to nasd_column_headings.mst
diff --git a/nasd_footer_lower.mustache b/nasd_footer_lower.mst
similarity index 100%
rename from nasd_footer_lower.mustache
rename to nasd_footer_lower.mst
diff --git a/nasd_footer_upper.mustache b/nasd_footer_upper.mst
similarity index 100%
rename from nasd_footer_upper.mustache
rename to nasd_footer_upper.mst
diff --git a/nasd_header.mustache b/nasd_header.mst
similarity index 100%
rename from nasd_header.mustache
rename to nasd_header.mst
diff --git a/nasd_header_lower.mustache b/nasd_header_lower.mst
similarity index 100%
rename from nasd_header_lower.mustache
rename to nasd_header_lower.mst
diff --git a/nasd_header_upper.mustache b/nasd_header_upper.mst
similarity index 100%
rename from nasd_header_upper.mustache
rename to nasd_header_upper.mst
diff --git a/nasd_notes1.mustache b/nasd_notes1.mst
similarity index 100%
rename from nasd_notes1.mustache
rename to nasd_notes1.mst
diff --git a/nasd_notes2.mustache b/nasd_notes2.mst
similarity index 100%
rename from nasd_notes2.mustache
rename to nasd_notes2.mst
diff --git a/nasd_supplemental.mustache b/nasd_supplemental.mst
similarity index 100%
rename from nasd_supplemental.mustache
rename to nasd_supplemental.mst
diff --git a/nasd_supplemental_report.mustache b/nasd_supplemental_report.mst
similarity index 100%
rename from nasd_supplemental_report.mustache
rename to nasd_supplemental_report.mst
diff --git a/numeric_summary.mustache b/numeric_summary.mst
similarity index 100%
rename from numeric_summary.mustache
rename to numeric_summary.mst
diff --git a/reg_d_group_basic.mustache b/reg_d_group_basic.mst
similarity index 100%
rename from reg_d_group_basic.mustache
rename to reg_d_group_basic.mst
diff --git a/reg_d_group_column_headings.mustache 
b/reg_d_group_column_headings.mst
similarity index 100%
rename from reg_d_group_column_headings.mustache
rename to reg_d_group_column_headings.mst
diff --git a/reg_d_group_footer_lower.mustache b/reg_d_group_footer_lower.mst
similarity index 100%
rename from reg_d_group_footer_lower.mustache
rename to reg_d_group_footer_lower.mst
diff --git a/reg_d_group_footer_upper.mustache b/reg_d_group_footer_upper.mst
similarity index 100%
rename from reg_d_group_footer_upper.mustache
rename to reg_d_group_footer_upper.mst
diff --git a/reg_d_group_header.mustache b/reg_d_group_header.mst
similarity index 100%
rename from reg_d_group_header.mustache
rename to reg_d_group_header.mst
diff --git a/reg_d_group_header_lower.mustache b/reg_d_group_header_lower.mst
similarity index 100%
rename from reg_d_group_header_lower.mustache
rename to reg_d_group_header_lower.mst
diff --git a/reg_d_group_header_upper.mustache b/reg_d_group_header_upper.mst
similarity index 100%
rename from reg_d_group_header_upper.mustache
rename to reg_d_group_header_upper.mst
diff --git a/reg_d_group_narrative_summary.mustache 
b/reg_d_group_narrative_summary.mst
similarity index 100%
rename from reg_d_group_narrative_summary.mustache
rename to reg_d_group_narrative_summary.mst
diff --git a/reg_d_group_narrative_summary2.mustache 
b/reg_d_group_narrative_summary2.mst
similarity index 100%
rename from reg_d_group_narrative_summary2.mustache
rename to reg_d_group_narrative_summary2.mst
diff --git a/reg_d_group_supplemental_report.mustache 
b/reg_d_group_supplemental_report.mst
similarity index 100%
rename from reg_d_group_supplemental_report.mustache
rename to reg_d_group_supplemental_report.mst
diff --git a/reg_d_individual_cover_page.mustache 
b/reg_d_individual_cover_page.mst
similarity index 100%
rename from reg_d_individual_cover_page.mustache
rename to reg_d_individual_cover_page.mst
diff --git a/reg_d_individual_cur.mustache b/reg_d_individual_cur.mst
similarity index 100%
rename from reg_d_individual_cur.mustache
rename to reg_d_individual_cur.mst
diff --git a/reg_d_individual_cur_irr.mustache b/reg_d_individual_cur_irr.mst
similarity index 100%
rename from reg_d_individual_cur_irr.mustache
rename to reg_d_individual_cur_irr.mst
diff --git a/reg_d_individual_footer_lower.mustache 
b/reg_d_individual_footer_lower.mst
similarity index 100%
rename from reg_d_individual_footer_lower.mustache
rename to reg_d_individual_footer_lower.mst
diff --git a/reg_d_individual_footer_upper.mustache 
b/reg_d_individual_footer_upper.mst
similarity index 100%
rename from reg_d_individual_footer_upper.mustache
rename to reg_d_individual_footer_upper.mst
diff --git a/reg_d_individual_guar_irr.mustache b/reg_d_individual_guar_irr.mst
similarity index 100%
rename from reg_d_individual_guar_irr.mustache
rename to reg_d_individual_guar_irr.mst
diff --git a/reg_d_individual_header.mustache b/reg_d_individual_header.mst
similarity index 100%
rename from reg_d_individual_header.mustache
rename to reg_d_individual_header.mst
diff --git a/reg_d_individual_notes1.mustache b/reg_d_individual_notes1.mst
similarity index 100%
rename from reg_d_individual_notes1.mustache
rename to reg_d_individual_notes1.mst
diff --git a/reg_d_individual_notes2.mustache b/reg_d_individual_notes2.mst
similarity index 100%
rename from reg_d_individual_notes2.mustache
rename to reg_d_individual_notes2.mst
diff --git a/reg_d_individual_notes3.mustache b/reg_d_individual_notes3.mst
similarity index 100%
rename from reg_d_individual_notes3.mustache
rename to reg_d_individual_notes3.mst
diff --git a/reg_d_individual_supplemental_report.mustache 
b/reg_d_individual_supplemental_report.mst
similarity index 100%
rename from reg_d_individual_supplemental_report.mustache
rename to reg_d_individual_supplemental_report.mst
diff --git a/supplemental_report.mustache b/supplemental_report.mst
similarity index 100%
rename from supplemental_report.mustache
rename to supplemental_report.mst
diff --git a/tabular_details.mustache b/tabular_details.mst
similarity index 100%
rename from tabular_details.mustache
rename to tabular_details.mst
diff --git a/tabular_details2.mustache b/tabular_details2.mst
similarity index 100%
rename from tabular_details2.mustache
rename to tabular_details2.mst
diff --git a/workhorse.make b/workhorse.make
index cd0b4e5..1f03430 100644
--- a/workhorse.make
+++ b/workhorse.make
@@ -896,7 +896,7 @@ test_dir       := $(exec_prefix)/test
 touchstone_dir := $(exec_prefix)/touchstone
 
 data_files := \
-  $(wildcard $(addprefix $(srcdir)/,*.ico *.mustache *.png *.xml *.xrc *.xsd 
*.xsl)) \
+  $(wildcard $(addprefix $(srcdir)/,*.ico *.mst *.png *.xml *.xrc *.xsd 
*.xsl)) \
 
 help_files := \
   $(wildcard $(addprefix $(srcdir)/,*.html)) \



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/header.mustache b/header.mst
similarity index 100%
rename from header.mustache
rename to header.mst
diff --git a/ledger_pdf_generator_wx.cpp b/ledger_pdf_generator_wx.cpp
index c9e017e..846022a 100644
--- a/ledger_pdf_generator_wx.cpp
+++ b/ledger_pdf_generator_wx.cpp
@@ -292,13 +292,13 @@ class html_interpolator
 
     std::string load_partial_from_file(std::string const& file) const
     {
-        std::ifstream ifs(AddDataDir(file + ".mustache"));
+        std::ifstream ifs(AddDataDir(file + ".mst"));
         if(!ifs)
             {
             alarum()
                 << "Template file \""
                 << file
-                << ".mustache\" not found."
+                << ".mst\" not found."
                 << std::flush
                 ;
             }
@@ -683,7 +683,7 @@ class page
   protected:
     // Helper method for rendering the contents of the given external template,
     // which is expected to be found in the file with the provided name and
     // ".mustache" extension in the data directory.
     //
     // Return the height of the page contents.
     int render_page_template
@@ -683,7 +683,7 @@ class page
     // Helper method for rendering the contents of the given external template,
     // which is expected to be found in the file with the provided name and
-    // ".mustache" extension in the data directory.
+    // ".mst" extension in the data directory.
     //
     // Return the height of the page contents.